import {
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
  line,
} from 'd3';

export const lineGraph = () => {
  let width;
  let height;
  let data;
  let xValue;
  let yValue;
  let margin;
  let xLabel;
  let yLabel;

  const my = (selection) => {
    const x = d3
      .scaleTime()
      .domain(d3.extent(data, (d) => d.timestamp))
      .range([margin.left, width - margin.right]);

    const y = scaleLinear()
      .domain(extent(data, yValue))
      .range([
        height - margin.bottom,
        margin.top,
      ]);

    const tooltip = d3
      .select('#graph-container')
      .append('div')
      .attr('class', 'tooltip')
      .style('opacity', 0);

    const lineGenerator = line()
      .x((d) => x(xValue(d)))
      .y((d) => y(yValue(d)));

    const path = selection
      .selectAll('path')
      .data([data])
      .join('path')
      .attr('d', lineGenerator)
      .attr('fill', 'none')
      .attr('stroke', 'steelblue')
      .attr('stroke-width', 2);

    const formatDate = d3.timeFormat('%b %d, %Y');

    selection
      .selectAll('.x-axis')
      .data([data])
      .join('g')
      .attr('class', 'x-axis')
      .attr(
        'transform',
        `translate(0,${height - margin.bottom})`
      )
      .call(axisBottom(x))
      .append('text')
      .attr('class', 'axis-label')
      .text(xLabel)
      .attr(
        'x',
        margin.left +
          (width - margin.left - margin.right) / 2
      )
      .attr('y', 50); // Relative to the x axis.

    selection
      .selectAll('.y-axis')
      .data([data])
      .join('g')
      .attr('class', 'y-axis')
      .attr(
        'transform',
        `translate(${margin.left},0)`
      )
      .call(axisLeft(y))
      .append('text')
      .attr('class', 'axis-label')
      .text(yLabel)
      .attr('transform', 'rotate(-90)')
      .attr(
        'x',
        -(
          margin.top +
          (height - margin.top - margin.bottom) /
            2
        )
      )
      .attr('y', -50); // Relative to the y axis
  };

  my.width = function (_) {
    return arguments.length
      ? ((width = +_), my)
      : width;
  };

  my.height = function (_) {
    return arguments.length
      ? ((height = +_), my)
      : height;
  };

  my.data = function (_) {
    return arguments.length
      ? ((data = _), my)
      : data;
  };

  my.xValue = function (_) {
    return arguments.length
      ? ((xValue = _), my)
      : xValue;
  };

  my.yValue = function (_) {
    return arguments.length
      ? ((yValue = _), my)
      : yValue;
  };

  my.margin = function (_) {
    return arguments.length
      ? ((margin = _), my)
      : margin;
  };

  my.xLabel = function (_) {
    return arguments.length
      ? ((xLabel = _), my)
      : xLabel;
  };

  my.yLabel = function (_) {
    return arguments.length
      ? ((yLabel = _), my)
      : yLabel;
  };

  return my;
};
