import {
  scaleBand,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
} from 'd3';

export const barGraph = () => {
  let width;
  let height;
  let data;
  let xValue;
  let yValue;
  let margin;
  let xLabel;
  let yLabel;

  const my = (selection) => {
    const x = scaleBand()
      .domain(data.map(xValue))
      .range([margin.left, width - margin.right])
      .padding(0.1);

    const y = scaleLinear()
      .domain([0, extent(data, yValue)[1]])
      .range([height - margin.bottom, margin.top]);

    selection
      .selectAll('rect')
      .data(data)
      .join('rect')
      .attr('x', d => x(xValue(d)))
      .attr('y', d => y(yValue(d)))
      .attr('width', x.bandwidth())
      .attr('height', d => y(0) - y(yValue(d)))
      .attr('fill', 'steelblue');

    const formatDate = d3.timeFormat("%b %d, %Y");

    selection
      .selectAll('.x-axis')
      .data([data])
      .join('g')
      .attr('class', 'x-axis')
      .attr(
        'transform',
        `translate(0,${height - margin.bottom})`
      )
      .call(axisBottom(x))
      .append('text')
      .attr('class','axis-label')
      .text(xLabel)
      .attr('x', margin.left + (width - margin.left - margin.right) / 2)
      .attr('y', 50) // Relative to the x axis.

    selection
      .selectAll('.y-axis')
      .data([data])
      .join('g')
      .attr('class', 'y-axis')
      .attr('transform', `translate(${margin.left},0)`)
      .call(axisLeft(y))
      .append('text')
      .attr('class','axis-label')
      .text(yLabel)
      .attr('transform', 'rotate(-90)')
      .attr('x', -(margin.top + (height - margin.top - margin.bottom) / 2))
      .attr('y', -50); // Relative to the y axis
  };

  my.width = function (_) {
    return arguments.length ? ((width = +_), my) : width;
  };

  my.height = function (_) {
    return arguments.length ? ((height = +_), my) : height;
  };

  my.data = function (_) {
    return arguments.length ? ((data = _), my) : data;
  };

  my.xValue = function (_) {
    return arguments.length ? ((xValue = _), my) : xValue;
  };

  my.yValue = function (_) {
    return arguments.length ? ((yValue = _), my) : yValue;
  };

  my.margin = function (_) {
    return arguments.length ? ((margin = _), my) : margin;
  };

  my.xLabel = function (_) {
    return arguments.length ? ((xLabel = _), my) : xLabel;
  };

  my.yLabel = function (_) {
    return arguments.length ? ((yLabel = _), my) : yLabel;
  };

  return my;
};
