const drawChart = () => {
  const margin = { top: 10, right: 50, bottom: 50, left: 50 };
  const color = d3.scaleOrdinal(d3.schemeCategory10);

  const svg = d3
    .select(`#${chartId}`)
    .append("svg")
    .attr("width", width + margin.left + margin.right)
    .attr("height", height + margin.top + margin.bottom)
    .append("g")
    .attr("transform", `translate(${margin.left},${margin.top})`);

  const xAxisFormat = d3.timeFormat("%Y-%m-%d");

  const x = d3
    .scaleTime()
    .domain(d3.extent(data[0].values, (d) => d.metric_date))
    .range([0, width]);

  svg
    .append("g")
    .attr("transform", `translate(0,${height})`)
    .call(d3.axisBottom(x).tickFormat(xAxisFormat))
    .append("text")
    .attr("class", "axis-label")
    .attr("x", width / 2)
    .attr("y", 40)
    .attr("fill", "#000")
    .style("text-anchor", "middle")
    .text("Time Range");

  const y = d3
    .scaleLinear()
    .domain([
      0,
      d3.max(data, (metric) =>
        d3.max(metric.values, (d) => +d.value)
      ),
    ])
    .range([height, 0]);

  svg
    .append("g")
    .call(d3.axisLeft(y).tickFormat(d3.format(".0f")))
    .append("text")
    .attr("class", "axis-label")
    .attr("transform", "rotate(-90)")
    .attr("x", -height / 2)
    .attr("y", -40)
    .attr("fill", "#000")
    .style("text-anchor", "middle")
    .text("Metric Value");

  const line = d3
    .line()
    .x((d) => x(d.metric_date))
    .y((d) => y(+d.value));

  const lines = svg.selectAll(".line").data(data).enter().append("g");

  lines
    .append("path")
    .datum((d) => d.values)
    .attr("fill", "none")
    .attr("stroke", (d,i) => color(i))
    .attr("stroke-width", 1.5)
    .attr("d", line);

  const legend = svg
      ...
};


[
  {
     metric: 'metric1',
     values: [
       {metric_date: date1, value: value1},
       {metric_date: date2, value: value2},
       ...
     ]
   },
   {
     metric: 'metric2',
     values: [
       {metric_date: date1, value: value1},
       {metric_date: date2, value: value2},
       ...
     ]
   },
   ...
]



import { useState } from "react";

const services = {
  service1: ["metric1", "metric2", "metric3"],
  service2: ["metric4", "metric5", "metric6"],
};

const ServiceMetricSelector = () => {
  const [selectedService, setSelectedService] = useState(
    Object.keys(services)[0]
  );
  const [selectedMetrics, setSelectedMetrics] = useState([]);

  const handleServiceChange = (event) => {
    setSelectedService(event.target.value);
    setSelectedMetrics([]);
  };

  const handleMetricChange = (event) => {
    setSelectedMetrics(Array.from(event.target.selectedOptions, option => option.value));
  };

  return (
    <div>
      <select onChange={handleServiceChange}>
        {Object.keys(services).map((service) => (
          <option key={service} value={service}>
            {service}
          </option>
        ))}
      </select>
      <select multiple onChange={handleMetricChange}>
        {services[selectedService].map((metric) => (
          <option key={metric} value={metric}>
            {metric}
          </option>
        ))}
      </select>
    </div>
  );
};

export default ServiceMetricSelector;






const handleMetricChange = (event) => {
  const selectedOptions = Array.from(event.target.selectedOptions, option => option.value);
  setSelectedMetrics(selectedOptions);
  console.log(selectedOptions.join(', '));
};




<div className="service-metric-row">
          {/* <ServiceMetric className="service-metric" /> */}
          <div className="select-container">
      <select
        className="select-field"
        value={selectedService}
        onChange={handleServiceChange}
        name='service'
      >
        <option value="">Select a service</option>
        {Object.keys(services).map((service) => (
          <option key={service} value={service}>
            {service}
          </option>
        ))}
      </select>
      <select
        multiple
        value={selectedMetrics[0]}
        onChange={handleMetricChange}
        disabled={!selectedService}
        className="select-field"
        name="metric"
      >
        {renderMetricsOptions()}
      </select>
    </div>
        </div>
        
        
        
        
        
        
.service-metric-row {
  display: flex;
  align-items: center;
  margin-bottom: 10px;
  flex-wrap: wrap;
}

.service-metric {
  margin-right: 10px;
  flex-basis: 100%;
}

.select-container {
  flex-grow: 1;
  display: flex;
  justify-content: flex-end;
}

.select-field {
  padding: 10px;
  font-size: 16px;
  border-radius: 4px;
  border: 1px solid #ccc;
  background-color: #f2f2f2;
}

.select-field option:checked {
  background-color: #f8f8f8;
}

.select-field:focus {
  outline: none;
  border-color: #007bff;
}

.select-field:disabled {
  cursor: not-allowed;
}
