import {
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
  line,
} from 'd3';
import { lineGraph } from './LineGraph';

export const lineWithRange = () => {
  let width;
  let height;
  let data;
  let xValue;
  let yValue;
  let margin;
  let xLabel;
  let yLabel;
  let timeRange;
  let filteredData;
  

  const my = (selection) => {
//     const filteredData = data.filter(d => {
//       const diff = new Date() - new Date(d.timestamp);
//       const dayDiff = diff / (24 * 60 * 60 * 1000);
      
//       if (timeRange === '1m') {
//         return dayDiff <= 30;
//       } else if (timeRange === '6m') {
//         return dayDiff <= 30 * 6;
//       } else {
//         return true;
//       }
//     });
  
  // const line = new lineGraph('#graph-container');
    
  const sel = document.querySelector('#time-range');
  
  sel.addEventListener('change', () => {
  timeRange = sel.value
  console.log(timeRange);
  

  if (timeRange === '1m') {
    // Filter data for last 30 days
    const endDate = new Date();
    const startDate = new Date(endDate.getTime() - 30 * 24 * 60 * 60 * 1000);
    filteredData = data.filter(d => d.timestamp >= startDate && d.timestamp <= endDate);
  } else if (timeRange === '6m') {
    // Filter data for last 6 months
    const endDate = new Date();
    const startDate = new Date(endDate.getTime() - 6 * 30 * 24 * 60 * 60 * 1000);
    filteredData = data.filter(d => d.timestamp >= startDate && d.timestamp <= endDate);
  } else if (timeRange === '1y') {
    // Filter data for last 1 year
    const endDate = new Date();
    const startDate = new Date(endDate.getTime() - 365 * 24 * 60 * 60 * 1000);
    filteredData = data.filter(d => d.timestamp >= startDate && d.timestamp <= endDate);
  }
    
  console.log(filteredData);

  // Update the data and scales of the graph
  // line.data(filteredData);
  // line.x.domain(d3.extent(filteredData, d => d.timestamp));
  // line.y.domain([0, d3.max(filteredData, d => +d.value)]);
  // line.update();
});
    
    const x = d3
      .scaleTime()
      .domain(d3.extent(data, (d) => d.timestamp))
      .range([margin.left, width - margin.right]);

    const y = scaleLinear()
      .domain(extent(data, yValue))
      .range([
        height - margin.bottom,
        margin.top,
      ]);

    const lineGenerator = line()
      .x((d) => x(xValue(d)))
      .y((d) => y(yValue(d)));

    const path = selection
      .selectAll('path')
      .data([data])
      .join('path')
      .attr('d', lineGenerator)
      .attr('fill', 'none')
      .attr('stroke', 'steelblue')
      .attr('stroke-width', 2);

    const formatDate = d3.timeFormat('%b %d, %Y');

    selection
      .selectAll('.x-axis')
      .data([filteredData])
      .join('g')
      .attr('class', 'x-axis')
      .attr(
        'transform',
        `translate(0,${height - margin.bottom})`
      )
      .call(axisBottom(x))
      .append('text')
      .attr('class', 'axis-label')
      .text(xLabel)
      .attr(
        'x',
        margin.left +
          (width - margin.left - margin.right) / 2
      )
      .attr('y', 50); // Relative to the x axis.

    selection
      .selectAll('.y-axis')
      .data([data])
      .join('g')
      .attr('class', 'y-axis')
      .attr(
        'transform',
        `translate(${margin.left},0)`
      )
      .call(axisLeft(y))
      .append('text')
      .attr('class', 'axis-label')
      .text(yLabel)
      .attr('transform', 'rotate(-90)')
      .attr(
        'x',
        -(
          margin.top +
          (height - margin.top - margin.bottom) /
            2
        )
      )
      .attr('y', -50); // Relative to the y axis
  };

  my.width = function (_) {
    return arguments.length
      ? ((width = +_), my)
      : width;
  };

  my.height = function (_) {
    return arguments.length
      ? ((height = +_), my)
      : height;
  };

  my.data = function (_) {
    return arguments.length
      ? ((data = _), my)
      : data;
  };

  my.xValue = function (_) {
    return arguments.length
      ? ((xValue = _), my)
      : xValue;
  };

  my.yValue = function (_) {
    return arguments.length
      ? ((yValue = _), my)
      : yValue;
  };

  my.margin = function (_) {
    return arguments.length
      ? ((margin = _), my)
      : margin;
  };

  my.xLabel = function (_) {
    return arguments.length
      ? ((xLabel = _), my)
      : xLabel;
  };

  my.yLabel = function (_) {
    return arguments.length
      ? ((yLabel = _), my)
      : yLabel;
  };
  
  my.timeRange = function (_) {
  return arguments.length ? ((timeRange = _), my) : timeRange;
};

  return my;
};
