import * as d3 from "d3";
import { useEffect, useState } from "react";
import axios from "axios";
import { timeParse } from "d3-time-format";

const LineChart = (props) => {
  const { service, metric, chartId, width, height } = props;

  const [data, setData] = useState([]);
  const [chartRendered, setChartRendered] = useState(false);

  useEffect(() => {
    const fetchData = async () => {
      try {
        const response = await axios.get(
          `http://localhost:8800/services/${service}/${metric}`
        );
        const dat = response.data;
        console.log(`http://localhost:8800/services/${service}/${metric}`)
        const parseDate = timeParse("%Y-%m-%dT%H:%M:%S.%L%f");
        const parseDate2 = d3.timeParse("%Y-%m-%dT%H:%M:%S.%L%Z");

        console.log(dat);

        dat.forEach((d) => {
        
        if (service === "fk-sp-claim-orchestrator"){
            //   console.log("before:", d.metric_date);
            d.metric_date = parseDate2(d.metric_date);
            //   console.log("after:", d.metric_date);
        }
        else{
          d.metric_date = parseDate(d.metric_date);
        }
        
        });

        setData(dat);
        console.log(dat);
      } catch (error) {
        console.error("Error fetching data:", error);
      }
    };

    fetchData();
  }, [metric, service]);

  useEffect(() => {
    const drawChart = () => {
      const margin = { top: 10, right: 50, bottom: 50, left: 50 };

      const svg = d3
        .select(`#${chartId}`)
        .append("svg")
        .attr("width", width + margin.left + margin.right)
        .attr("height", height + margin.top + margin.bottom)
        .append("g")
        .attr("transform", `translate(${margin.left},${margin.top})`);

      const xAxisFormat = d3.timeFormat("%Y-%m-%d");

      const x = d3
        .scaleTime()
        .domain(d3.extent(data, (d) => d.metric_date))
        .range([0, width]);

      svg
        .append("g")
        .attr("transform", `translate(0,${height})`)
        .call(d3.axisBottom(x).tickFormat(xAxisFormat))
        .append("text")
        .attr("class", "axis-label")
        .attr("x", width / 2)
        .attr("y", 40)
        .attr("fill", "#000")
        .style("text-anchor", "middle")
        .text("Time Range");

      const y = d3
        .scaleLinear()
        .domain([0, d3.max(data, (d) => +d.value)])
        .range([height, 0]);

      svg
        .append("g")
        .call(d3.axisLeft(y).tickFormat(d3.format(".0f")))
        .append("text")
        .attr("class", "axis-label")
        .attr("transform", "rotate(-90)")
        .attr("x", -height / 2)
        .attr("y", -40)
        .attr("fill", "#000")
        .style("text-anchor", "middle")
        .text("Metric Value");

      const line = d3
        .line()
        .x((d) => x(d.metric_date))
        .y((d) => y(+d.value));

      svg
        .append("path")
        .datum(data)
        .attr("fill", "none")
        .attr("stroke", "steelblue")
        .attr("stroke-width", 1.5)
        .attr("d", line);

      const legend = svg
        .append("g")
        .attr("class", "legend")
        .attr("transform", `translate(${width - margin.right}, ${margin.top})`);

      legend
        .append("rect")
        .attr("width", 20)
        .attr("height", 20)
        .attr("fill", "steelblue");

      legend
        .append("text")
        .attr("x", 30)
        .attr("y", 15)
        .attr("fill", "steelblue")
        .text(metric);
    };

    if (!chartRendered && data.length > 0) {
      drawChart();
      setChartRendered(true);
    }
  }, [service,data, chartRendered, width, height, chartId,metric]);

  return (
    <div>
      <div id={chartId}></div>
    </div>
  );
};

export default LineChart;
